@@ -101,6 +101,20 @@ void set_menu_item_label(GtkMenuItem *item, const gchar *text)
 	gtk_label_set_markup(GTK_LABEL(children->data), text);		
 }
 
+static
+void set_button_label(GtkMenuItem *item, const gchar *text)
+{
+	GList *children = gtk_container_get_children(GTK_CONTAINER(item));
+	
+	if (children == NULL) {
+		g_printerr("ERROR: set_menu_item_label() expects a GtkMenuItem, which already contains a label.\n");
+		return;
+	}
+	
+	gtk_label_set_markup(GTK_LABEL(children->data), text);		
+}
+
+
 GtkWidget* create_mainwin(Note *note) {
 	
 	UserInterface *ui = note->ui;
@@ -261,14 +275,14 @@ GtkWidget* create_mainwin(Note *note) {
 	menu_font_large = gtk_action_create_menu_item(action_font_large);
 	menu_font_huge = gtk_action_create_menu_item(action_font_huge);
 	
-	set_menu_item_label(GTK_MENU_ITEM(menu_bold), "<b>Bold</b>");
-	set_menu_item_label(GTK_MENU_ITEM(menu_italic), "<i>Italic</i>");
-	set_menu_item_label(GTK_MENU_ITEM(menu_strike), "<s>Strikeout</s>");
-	set_menu_item_label(GTK_MENU_ITEM(menu_highlight), "<span background=\"yellow\">Highlight</span>");
-	set_menu_item_label(GTK_MENU_ITEM(menu_fixed), "<tt>Fixed Width</tt>");
+	set_menu_item_label(GTK_MENU_ITEM(menu_bold),       "<b>Bold</b>");
+	set_menu_item_label(GTK_MENU_ITEM(menu_italic),     "<i>Italic</i>");
+	set_menu_item_label(GTK_MENU_ITEM(menu_strike),     "<s>Strikeout</s>");
+	set_menu_item_label(GTK_MENU_ITEM(menu_highlight),  "<span background=\"yellow\">Highlight</span>");
+	set_menu_item_label(GTK_MENU_ITEM(menu_fixed),      "<tt>Fixed Width</tt>");
 	set_menu_item_label(GTK_MENU_ITEM(menu_font_small), "<span size=\"small\">Small</span>");
 	set_menu_item_label(GTK_MENU_ITEM(menu_font_large), "<span size=\"large\">Large</span>");
-	set_menu_item_label(GTK_MENU_ITEM(menu_font_huge), "<span size=\"x-large\">Huge</span>");
+	set_menu_item_label(GTK_MENU_ITEM(menu_font_huge),  "<span size=\"x-large\">Huge</span>");
 	
 	gtk_menu_shell_append(text_style_menu, menu_bold);
 	gtk_menu_shell_append(text_style_menu, menu_italic);
@@ -288,8 +302,30 @@ GtkWidget* create_mainwin(Note *note) {
 
 	
 	
-	
 	/* MAIN MENU */
+#ifdef HILDON_HAS_APP_MENU
+	 main_menu = hildon_app_menu_new();
+
+	menu_new = gtk_button_new_with_label("New"); /*gtk_action_create_tool_item(action_new);*/
+	menu_quit = gtk_button_new_with_label("Quit");  /*gtk_action_create_tool_item(action_quit);*/
+	GtkWidget *one = gtk_button_new_with_label("Something longer");
+	GtkWidget *two = gtk_button_new_with_label("Something very very long");
+	GtkWidget *copy = gtk_button_new_with_label("Highlight");
+	GtkWidget *paste = gtk_button_new_with_label("Strikethrough");
+
+	set_button_label(paste, "<b>Bold</b>");
+	set_button_label(copy, "<i>Italic</i>");
+
+	hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(menu_new));
+	hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(menu_quit));
+	hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(one));
+	hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(two));
+	hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(paste));
+	hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(copy));
+
+	hildon_window_set_app_menu(HILDON_WINDOW(mainwin), HILDON_APP_MENU(main_menu));
+	
+#else
 	main_menu = gtk_menu_new();
 	
 	menu_new = gtk_action_create_menu_item(action_new);
@@ -297,8 +333,6 @@ GtkWidget* create_mainwin(Note *note) {
 	gtk_menu_item_set_submenu(menu_text_style, text_style_menu);
 	menu_quit = gtk_action_create_menu_item(action_quit);
 	
-	
-	
 	gtk_menu_shell_append(main_menu, menu_new);
 	gtk_menu_shell_append(main_menu, menu_new);
 	gtk_menu_shell_append(main_menu, gtk_separator_menu_item_new());
@@ -306,9 +340,13 @@ GtkWidget* create_mainwin(Note *note) {
 	gtk_menu_shell_append(main_menu, gtk_separator_menu_item_new());
 	gtk_menu_shell_append(main_menu, menu_quit);
 	
-
 	/* Must be at the end of the menu definition */
 	hildon_window_set_menu(HILDON_WINDOW(mainwin), GTK_MENU(main_menu));
+#endif
+	
+
+	
+	
 
 	/* TOOLBAR */
 	toolbar = gtk_toolbar_new();
@@ -452,7 +490,7 @@ GtkWidget* create_mainwin(Note *note) {
 	
 	g_signal_connect(action_notes, "activate",
 			G_CALLBACK(on_notes_button_clicked),
-			buffer);
+			mainwin);
 	
 	g_signal_connect(action_delete, "activate",
 			G_CALLBACK(on_delete_button_clicked),
