@@ -64,11 +64,28 @@ AppData* get_app_data() {
 		_app_data->client = client;
 		_app_data->font_size = font_size;
 		_app_data->program = hildon_program_get_instance();
+		_app_data->fullscreen = FALSE;
 	}
 	
 	return _app_data;
 }
 
+/* char *_bullets[] = {"\u2022 ", "\u2218 ", "\u2023 ", "\u2043 ", "\u204d ", "\u2219 ", "\u25e6 "}; */
+/* These 3 bullets work with diablo and standard font */
+char *_bullets[] = {"\u2022 ", "\u25e6 ", "\u2219 "};
+const gchar* get_bullet_by_depth(gint depth) {
+	if (depth <= 0) {
+		g_printerr("ERROR: get_bullets_by_depth(): depth must be at least 1.\n");
+		return "\u2022 ";
+	}
+	return _bullets[(depth - 1) % 3];
+}
+
+const gchar* get_bullet_by_depth_tag(GtkTextTag *tag) {
+	return get_bullet_by_depth(tag_get_depth(tag));
+}
+
+
 static
 gint compare_notes_by_change_date(gconstpointer a, gconstpointer b) {
 	
