@@ -32,6 +32,7 @@ Note* note_create_new()
 	Note *note = g_new0(Note, 1);
 	UserInterface *ui = g_new0(UserInterface, 1);
 	note->ui = ui;
+	note->active_tags = NULL;
 	return note;
 }
 
@@ -41,6 +42,7 @@ void note_free(Note *note)
 	g_free(note->filename);
 	g_free(note->title);
 	g_free(note->version);
+	g_slist_free(note->active_tags);
 }
 
 /* Not needed right now. Maybe later again */
@@ -297,7 +299,16 @@ void note_show(Note *note)
 	buffer = note->ui->buffer;
 	window = GTK_WINDOW(note->ui->window);
 	
-	gtk_window_set_default_size(window, 500, 300);
+	/* Set window width/height, otherwise scroll to cursor doesn't work correctly */
+	gtk_window_set_default_size(window, 720, 420);
+	
+	/* Set to fullscreen or not */
+	if (app_data->fullscreen) {
+		gtk_window_fullscreen(GTK_WINDOW(note->ui->window));
+	} else {
+		gtk_window_unfullscreen(GTK_WINDOW(note->ui->window));
+	}
+	
 	hildon_program_add_window(app_data->program, HILDON_WINDOW(window));
 	
 	/* Block signals on TextBuffer until we are done with initializing the content. This is to prevent saves etc. */
@@ -315,7 +326,7 @@ void note_show(Note *note)
 	note_format_title(buffer);
 	note_set_window_title_from_buffer(window, buffer); /* Replace this. And use note->title instead */
 	
-	gtk_widget_show(GTK_WIDGET(window));	
+	gtk_widget_show(GTK_WIDGET(window));
 	
 	gtk_text_buffer_set_modified(buffer, FALSE);
 	
@@ -363,8 +374,57 @@ void note_show_existing(Note *note)
 	gtk_text_buffer_place_cursor(buffer, &iter);
 	
 	/* Scroll to cursor position */
-	/* TODO: Does not scroll. Maybe we first need to show the widget?! */
-	gtk_text_view_scroll_to_iter(note->ui->view, &iter, 0.0, TRUE, 0.5, 0.0);
+	gtk_text_view_scroll_to_mark(note->ui->view, gtk_text_buffer_get_insert(buffer), 0.0, TRUE, 0.0, 0.5);
+}
+
+void note_add_active_tag_by_name(Note *note, const gchar *tag_name)
+{
+	note_add_active_tag(note, gtk_text_tag_table_lookup(note->ui->buffer->tag_table, tag_name));
+}
+
+void note_remove_active_tag_by_name(Note *note, const gchar *tag_name)
+{
+	note_remove_active_tag(note, gtk_text_tag_table_lookup(note->ui->buffer->tag_table, tag_name));
+}
+
+/**
+ * Add a tag to the list of active_tags, if it is not yet in the list.
+ */
+void note_add_active_tag(Note *note, GtkTextTag *tag)
+{
+	if (note == NULL) {
+		g_printerr("ERROR: note_add_active_tag: note is NULL\n");
+		return;
+	}
+	if (tag == NULL) {
+		g_printerr("ERROR: note_add_active_tag: tag is NULL\n");
+		return;
+	}
+	
+	GSList *tags = note->active_tags;
+	while (tags != NULL) {
+		if (strcmp(((GtkTextTag*)tags->data)->name, tag->name) == 0) {
+			return;
+		}
+		tags = tags->next;
+	}
+	note->active_tags = g_slist_prepend(note->active_tags, tag);
+}
+
+/**
+ * Removes a tag from the list of active_tags if it is in this list.
+ */
+void note_remove_active_tag(Note *note, GtkTextTag *tag)
+{
+	GSList *tags = note->active_tags;
+	while (tags != NULL) {
+		if (strcmp(GTK_TEXT_TAG(tags->data)->name, tag->name) == 0) {
+			note->active_tags = g_slist_remove(note->active_tags, tags->data);
+			return;
+		}
+		tags = tags->next;
+	}
 }
 
 
+
